'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Semantyk 
Package | `semantyk`

Daniel Bakas Amuchastegui\
August 31, 2017

Copyright © Semantyk 2021. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__author__ = 'Semantyk'
__date__ = '2017-08-31'
__description__ = 'Ideas Wonder.'
__email__ = 'contact@semantyk.com'
__version__ = '0.0.77'


# From Import Declarations | Package Imports
from . import archive

# From Import Declarations | Module Imports
from .archive import *
